@@ -1,6 +1,7 @@
+use pyo3::exceptions::PyValueError;
 use pyo3::intern;
 use pyo3::prelude::*;
-use pyo3::types::{PyDate, PyDict, PyString};
+use pyo3::types::{PyDict, PyString};
 use speedate::{Date, Time};
 use strum::EnumMessage;
 
@@ -8,29 +9,30 @@ use crate::build_tools::{is_strict, py_schema_error_type};
 use crate::errors::{ErrorType, ErrorTypeDefaults, ValError, ValResult};
 use crate::input::{EitherDate, Input};
 
-use crate::tools::SchemaDict;
 use crate::validators::datetime::{NowConstraint, NowOp};
 
-use super::Exactness;
 use super::{BuildValidator, CombinedValidator, DefinitionsBuilder, ValidationState, Validator};
+use super::{Exactness, TemporalUnitMode};
 
 #[derive(Debug, Clone)]
 pub struct DateValidator {
     strict: bool,
     constraints: Option<DateConstraints>,
+    val_temporal_unit: TemporalUnitMode,
 }
 
 impl BuildValidator for DateValidator {
     const EXPECTED_TYPE: &'static str = "date";
 
     fn build(
-        schema: &PyDict,
-        config: Option<&PyDict>,
+        schema: &Bound<'_, PyDict>,
+        config: Option<&Bound<'_, PyDict>>,
         _definitions: &mut DefinitionsBuilder<CombinedValidator>,
     ) -> PyResult<CombinedValidator> {
         Ok(Self {
             strict: is_strict(schema, config)?,
             constraints: DateConstraints::from_py(schema)?,
+            val_temporal_unit: TemporalUnitMode::from_config(config)?,
         }
         .into())
     }
@@ -39,19 +41,19 @@ impl BuildValidator for DateValidator {
 impl_py_gc_traverse!(DateValidator {});
 
 impl Validator for DateValidator {
-    fn validate<'data>(
+    fn validate<'py>(
         &self,
-        py: Python<'data>,
-        input: &'data impl Input<'data>,
-        state: &mut ValidationState,
-    ) -> ValResult<'data, PyObject> {
+        py: Python<'py>,
+        input: &(impl Input<'py> + ?Sized),
+        state: &mut ValidationState<'_, 'py>,
+    ) -> ValResult<PyObject> {
         let strict = state.strict_or(self.strict);
-        let date = match input.validate_date(strict) {
+        let date = match input.validate_date(strict, self.val_temporal_unit) {
             Ok(val_match) => val_match.unpack(state),
             // if the error was a parsing error, in lax mode we allow datetimes at midnight
             Err(line_errors @ ValError::LineErrors(..)) if !strict => {
                 state.floor_exactness(Exactness::Lax);
-                date_from_datetime(input)?.ok_or(line_errors)?
+                date_from_datetime(input, self.val_temporal_unit)?.ok_or(line_errors)?
             }
             Err(otherwise) => return Err(otherwise),
         };
@@ -97,7 +99,7 @@ impl Validator for DateValidator {
                 }
             }
         }
-        Ok(date.try_into_py(py)?)
+        date.try_into_py(py, input)
     }
 
     fn get_name(&self) -> &str {
@@ -109,30 +111,34 @@ impl Validator for DateValidator {
 /// "exact date", e.g. has a zero time component.
 ///
 /// Ok(None) means that this is not relevant to dates (the input was not a datetime nor a string)
-fn date_from_datetime<'data>(input: &'data impl Input<'data>) -> Result<Option<EitherDate<'data>>, ValError<'data>> {
-    let either_dt = match input.validate_datetime(false, speedate::MicrosecondsPrecisionOverflowBehavior::Truncate) {
-        Ok(val_match) => val_match.into_inner(),
-        // if the error was a parsing error, update the error type from DatetimeParsing to DateFromDatetimeParsing
-        // and return it
-        Err(ValError::LineErrors(mut line_errors)) => {
-            if line_errors.iter_mut().fold(false, |has_parsing_error, line_error| {
-                if let ErrorType::DatetimeParsing { error, .. } = &mut line_error.error_type {
-                    line_error.error_type = ErrorType::DateFromDatetimeParsing {
-                        error: std::mem::take(error),
-                        context: None,
-                    };
-                    true
-                } else {
-                    has_parsing_error
+fn date_from_datetime<'py>(
+    input: &(impl Input<'py> + ?Sized),
+    mode: TemporalUnitMode,
+) -> Result<Option<EitherDate<'py>>, ValError> {
+    let either_dt =
+        match input.validate_datetime(false, speedate::MicrosecondsPrecisionOverflowBehavior::Truncate, mode) {
+            Ok(val_match) => val_match.into_inner(),
+            // if the error was a parsing error, update the error type from DatetimeParsing to DateFromDatetimeParsing
+            // and return it
+            Err(ValError::LineErrors(mut line_errors)) => {
+                if line_errors.iter_mut().fold(false, |has_parsing_error, line_error| {
+                    if let ErrorType::DatetimeParsing { error, .. } = &mut line_error.error_type {
+                        line_error.error_type = ErrorType::DateFromDatetimeParsing {
+                            error: std::mem::take(error),
+                            context: None,
+                        };
+                        true
+                    } else {
+                        has_parsing_error
+                    }
+                }) {
+                    return Err(ValError::LineErrors(line_errors));
                 }
-            }) {
-                return Err(ValError::LineErrors(line_errors));
+                return Ok(None);
             }
-            return Ok(None);
-        }
-        // for any other error, don't return it
-        Err(_) => return Ok(None),
-    };
+            // for any other error, don't return it
+            Err(_) => return Ok(None),
+        };
     let dt = either_dt.as_raw()?;
     let zero_time = Time {
         hour: 0,
@@ -158,7 +164,7 @@ struct DateConstraints {
 }
 
 impl DateConstraints {
-    fn from_py(schema: &PyDict) -> PyResult<Option<Self>> {
+    fn from_py(schema: &Bound<'_, PyDict>) -> PyResult<Option<Self>> {
         let py = schema.py();
         let c = Self {
             le: convert_pydate(schema, intern!(py, "le"))?,
@@ -175,9 +181,14 @@ impl DateConstraints {
     }
 }
 
-fn convert_pydate(schema: &PyDict, field: &PyString) -> PyResult<Option<Date>> {
-    match schema.get_as::<&PyDate>(field)? {
-        Some(date) => Ok(Some(EitherDate::Py(date).as_raw()?)),
+fn convert_pydate(schema: &Bound<'_, PyDict>, key: &Bound<'_, PyString>) -> PyResult<Option<Date>> {
+    match schema.get_item(key)? {
+        Some(value) => match value.validate_date(false, TemporalUnitMode::default()) {
+            Ok(v) => Ok(Some(v.into_inner().as_raw()?)),
+            Err(_) => Err(PyValueError::new_err(format!(
+                "'{key}' must be coercible to a date instance",
+            ))),
+        },
         None => Ok(None),
     }
 }
