@@ -15,7 +15,7 @@ use crate::input::{Input, InputType, StringMapping};
 use crate::py_gc::PyGcTraverse;
 use crate::recursion_guard::RecursionState;
 use crate::tools::SchemaDict;
-pub(crate) use config::ValBytesMode;
+pub(crate) use config::{TemporalUnitMode, ValBytesMode};
 
 mod any;
 mod arguments;
@@ -47,6 +47,7 @@ mod json_or_python;
 mod lax_or_strict;
 mod list;
 mod literal;
+mod missing_sentinel;
 mod model;
 mod model_fields;
 mod none;
@@ -574,6 +575,8 @@ fn build_validator_inner(
         call::CallValidator,
         // literals
         literal::LiteralValidator,
+        // missing sentinel
+        missing_sentinel::MissingSentinelValidator,
         // enums
         enum_::BuildEnumValidator,
         // any
@@ -741,6 +744,8 @@ pub enum CombinedValidator {
     FunctionCall(call::CallValidator),
     // literals
     Literal(literal::LiteralValidator),
+    // Missing sentinel
+    MissingSentinel(missing_sentinel::MissingSentinelValidator),
     // enums
     IntEnum(enum_::EnumValidator<enum_::IntEnumValidator>),
     StrEnum(enum_::EnumValidator<enum_::StrEnumValidator>),
