@@ -10,7 +10,7 @@ from dirty_equals import IsListOrTuple, IsStr
 
 from pydantic_core import ArgsKwargs, SchemaValidator, ValidationError, core_schema
 
-from ..conftest import Err, PyAndJson, assert_gc, is_free_threaded
+from ..conftest import Err, PyAndJson, assert_gc
 
 
 @pytest.mark.parametrize(
@@ -1516,10 +1516,10 @@ def test_dataclass_wrap_json():
     assert v.validate_json('{"a": "hello", "b": true}', strict=True) == FooDataclass(a='hello', b=True)
 
 
-@pytest.mark.xfail(is_free_threaded and sys.version_info < (3, 14), reason='GC leaks on free-threaded (<3.14)')
 @pytest.mark.xfail(
     condition=platform.python_implementation() == 'PyPy', reason='https://foss.heptapod.net/pypy/pypy/-/issues/3899'
 )
+@pytest.mark.skipif(platform.python_implementation() == 'GraalVM', reason='Cannot reliably trigger GC on GraalPy')
 @pytest.mark.parametrize('validator', [None, 'field', 'dataclass'])
 def test_leak_dataclass(validator):
     def fn():
